@@ -8,7 +8,7 @@ use Carp;
 use Zim::Utils;
 use Zim::Formats;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 our %_Formats;
 
@@ -267,13 +267,13 @@ any files under the document root will not be copied for any setting of MEDIA.
 sub clone {
 	my ($self, $page, %opt) = @_;
 	local $self->{cloning} = $page;
-	if ( $self->{format} and $page->{format} ) {
+	#if ( $self->{format} and $page->{format} ) {
 		$self->delete if $self->exists; # prevent mtime check etc.
 		my $tree = $page->get_parse_tree;
 		$self->_check_media($tree, $page, %opt);
 		$self->set_parse_tree($tree);
-	}
-	else { warn "Could not clone page: ". $page->name ."\n" }
+	#}
+	#else { warn "Could not clone page: ". $page->name ."\n" }
 }
 
 # Check for all file links and image in the parse tree if we need
