@@ -12,15 +12,15 @@
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-07-28 06:52+0000
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-11-06 23:51+0000
 # Last-Translator: Javier Rovegno Campos <tatadeluxe@gmail.com>
 # Language-Team: Spanish <es@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:05+0000
+# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -41,7 +41,10 @@ la página \'{name}\' ?',
   '<b>Enable Version Control</b>
 
 Version control is currently not enabled for this notebook.
-Do you want to enable it ?' => '',
+Do you want to enable it ?' => '<b>Habilitar Control de Versiones</b>
+
+El control de versiones no esta habilitado en este momento para este cuaderno de notas.
+¿Quiere habilitarlo?',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -63,7 +66,12 @@ ya existe.
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '',
+All changes since the last saved version will be lost !' => '<b>¿Restaurar página a la versión guardada?</b>
+
+¿Quiere usted restaurar la página: {page}
+a la versión guardada: {version} ?
+
+¡Todos los cambios desde la última versión guardada se perderán !',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -80,7 +88,7 @@ espacios de nombres por mes.
 ¿Desea actualizar este bloc de notas al nuevo formato?
 ',
   'Add \'tearoff\' strips to the menus' => 'Agregar \'barra de herramientas\' a los menús',
-  'Application show two text files side by side' => '',
+  'Application show two text files side by side' => 'La aplicación muestra dos archivos de texto uno junto al otro',
   'Application to compose email' => 'Aplicación para escribir correo electrónico',
   'Application to edit text files' => 'Aplicación para editar archivos de texto',
   'Application to open directories' => 'Aplicación para abrir directorios',
@@ -88,51 +96,57 @@ espacios de nombres por mes.
   'Attach _File|Attach external file' => 'Adjuntar _Archivo|Adjuntar archivo externo',
   'Attach external files' => 'Adjuntar archivos externos',
   'Auto-format entities' => 'Auto-formatear entidades',
-  'Auto-increment numbered lists' => '',
+  'Auto-increment numbered lists' => 'Listas numeradas con auto-incremento',
   'Auto-link CamelCase' => 'Auto-enlazar CamelCase',
   'Auto-link files' => 'Auto-enlazar archivos',
-  'Auto-save version on close' => '',
+  'Auto-save version on close' => 'Auto-guardar versión al cerrar',
   'Auto-select words' => 'Autoseleccionar palabras',
-  'Automatically increment items in a numbered list' => '',
+  'Automatically increment items in a numbered list' => 'Incrementar elementos automáticamente en una lista numerada',
   'Automatically link file names when you type' => 'Vincular automáticamente los nombres cuando los escriba',
   'Automaticly link CamelCase words when you type' => 'Enlazar automáticamente palabras CamelCase cuando se escriben',
   'Automaticly select the current word when you toggle the format' => 'Selecciona automáticamente la palabra actual cuando cambia el formato',
   'Bold' => 'Negrita',
   'Calen_dar|Show calendar' => 'Calen_dario|Mostrar calendario',
   'Calendar' => 'Calendario',
-  'Can not save a version without comment' => '',
+  'Can not find application "bzr"' => 'No se encontró la aplicación "bzr"',
+  'Can not find application "{name}"' => 'No se puede encontrar la aplicación "{name}"',
+  'Can not save a version without comment' => 'No se puede guardar una versión sin comentario',
   'Can not save to page: {name}' => 'No se puede guardar en la página: {name}',
   'Can\'t find {url}' => 'No se puede encontrar {url}',
   'Cha_nge' => 'Ca_mbiar',
   'Chars' => 'Caracteres',
   'Check _spelling|Spell check' => 'Revisar _ortografía|Revisar ortografía',
+  'Check checkbox lists recursive' => 'Revisa la lista checkbox recursiva',
+  'Checking a checkbox list item will also check any sub-items' => 'Revisando un ítem de lista checkbox, también revisará cualquier sub-ítem',
   'Choose {app_type}' => 'Elejir {app_type}',
-  'Co_mpare Page...' => '',
+  'Co_mpare Page...' => 'Co_mparar Página...',
   'Command' => 'Orden',
-  'Compare this version with' => '',
+  'Comment' => 'Comentario',
+  'Compare this version with' => 'Comparar esta versión con',
   'Copy Email Address' => 'Copiar dirección de correo electrónico',
   'Copy Location|Copy location' => 'Copiar enlace|Copiar enlace',
   'Copy _Link' => 'Copiar víncu _lo',
   'Could not delete page: {name}' => 'No se puede borrar la página: {name}',
-  'Could not get annotated source for page {page}' => '',
-  'Could not get changes for page: {page}' => '',
-  'Could not get file for page: {page}' => '',
-  'Could not get versions to compare' => '',
-  'Could not initialize version control' => '',
+  'Could not get annotated source for page {page}' => 'No se pudo obtener la fuente anotada para la página {page}',
+  'Could not get changes for page: {page}' => 'No se pudieron obtener los cambios para la página: {page}',
+  'Could not get changes for this notebook' => 'No pudo obtener cambios para este cuaderno',
+  'Could not get file for page: {page}' => 'No se pudo obtener el archivo para la página: {page}',
+  'Could not get versions to compare' => 'No se pudieron obtener las versiones a comparar',
+  'Could not initialize version control' => 'No se pudo inicializar el control de versiones',
   'Could not load page: {name}' => 'No se puede cargar la página: {name}',
   'Could not rename {from} to {to}' => 'No se puede renombrar de {from} a {to}',
   'Could not save page' => 'No se puede guardar la página',
-  'Could not save version' => '',
+  'Could not save version' => 'No se pudo guardar la versión',
   'Creating a new link directly opens the page' => 'Creando un nuevo vínculo se abre directamente la página',
-  'Creation Date' => '',
+  'Creation Date' => 'Fecha de Creación',
   'Cu_t|Cut' => 'Cor_tar|Cortar',
   'Current' => 'Actual',
   'Customise' => 'Modificar',
   'Date' => 'Fecha',
-  'Default notebook' => '',
+  'Default notebook' => 'Cuaderno por omisión',
   'Details' => 'Detalles',
-  'Diff Editor' => '',
-  'Diff editor' => '',
+  'Diff Editor' => 'Editor Diff',
+  'Diff editor' => 'Editor diff',
   'Directory' => 'Directorio',
   'Document Root' => 'Documento raíz',
   'E_quation...|Insert equation' => 'E_cuación...|Insertar ecuación',
@@ -141,20 +155,23 @@ espacios de nombres por mes.
   'Edit Image' => 'Editar imagen',
   'Edit Link' => 'Editar enlace',
   'Edit Query' => 'Editar Consulta',
-  'Edit _Source|Open source' => 'Editar _fuente|Código abierto',
+  'Edit _Source|Open source' => 'Editar _fuente|Abrir fuente',
   'Edit notebook' => 'Editar cuaderno de notas',
   'Edit text files "wiki style"' => 'Editar archivos de texto "estilo wiki"',
   'Editing' => 'Editando',
   'Email client' => 'Cliente de correo electrónico',
   'Enabled' => 'Habilitado',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => '',
   'Equation Editor' => 'Editor de ecuaciones',
   'Equation Editor Log' => 'Registro del editor de ecuaciones',
   'Expand side pane' => 'Expander panel lateral',
   'Export page' => 'Exportar página',
   'Exporting page {number}' => 'Exportar página {number}',
+  'Failed to cleanup SVN working copy.' => 'Falló limpiar la copia de trabajo SVN.',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'Falló cargar SVN plugin,
+¿Tiene instaladas las utilidades de subversion?',
   'Failed to load plugin: {name}' => 'Fallo al cargar el complemento: {name}',
+  'Failed update working copy.' => 'Falló actualizar la copia de trabajo.',
   'File browser' => 'Explorador de archivos',
   'File is not a text file: {file}' => 'El archivo no es de texto: {file}',
   'Filter' => 'Filtrar',
@@ -182,9 +199,10 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Height' => 'Altura',
   'Home Page' => 'Página personal',
   'Icon' => 'Icono',
-  'Id' => '',
+  'Id' => 'Id',
+  'Include all open checkboxes' => 'Incluye todas las checkboxes abiertas',
   'Index page' => 'Índice de páginas',
-  'Initial version' => '',
+  'Initial version' => 'Versión inicial',
   'Insert Date' => 'Insertar fecha',
   'Insert Image' => 'Insertar imagen',
   'Insert Link' => 'Inserta un vínculo',
@@ -197,14 +215,15 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Links to' => 'Víncular a',
   'Match c_ase' => 'Coincidir m_ayúsculas y minúsculas',
   'Media' => 'Media',
-  'Modification Date' => '',
+  'Modification Date' => 'Fecha de Modificación',
   'Name' => 'Nombre',
   'New notebook' => 'Cuaderno de notas nuevo',
   'New page' => 'Página nueva',
   'No such directory: {name}' => 'No es un directorio: {name}',
+  'No such file or directory: {name}' => 'Archivo o directorio no encontrado : {name}',
   'No such file: {file}' => 'No es un archivo: {file}',
   'No such notebook: {name}' => 'Cuaderno de notas no encontrado: {name}',
-  'No such page: {page}' => '',
+  'No such page: {page}' => 'Página no encontrada: {page}',
   'No such plugin: {name}' => 'Complemento no encontrado: {name}',
   'Normal' => 'Normal',
   'Not Now' => 'Ahora no',
@@ -227,19 +246,23 @@ inexistente, crea automáticamente una nueva página.',
   'Page Editable|Page editable' => 'Página Editable|Página editable',
   'Page name' => 'Nombre de página',
   'Pages' => 'Páginas',
-  'Please enter a comment for this version' => '',
-  'Please enter a name to save a copy of page: {page}' => '',
+  'Password' => 'Contraseña',
+  'Please enter a comment for this version' => 'Por favor, entre un comentario para esta versión',
+  'Please enter a name to save a copy of page: {page}' => 'Por favor, entre un nombre para guardar una copia de la página: {page}',
   'Please enter a {app_type}' => 'Introduzca {app_type}',
-  'Please give a page first' => '',
+  'Please give a page first' => 'Por favor, provea una página primero',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Por favor dé al menos un directorio para almacenar sus páginas.
 Para un nuevo bloc de notas este debería ser un directorio vacío.
 Por ejemplo un directorio "Notas" en su carpeta personal.',
-  'Please select a notebook first' => '',
-  'Please select a version first' => '',
+  'Please provide the password for
+{path}' => 'Por favor ingrese la contraseña para
+{path}',
+  'Please select a notebook first' => 'Por favor, selecciones un cuaderno primero',
+  'Please select a version first' => 'Por favor, seleccione una versión primero',
   'Plugin already loaded: {name}' => 'Complemento ya cargado: {name}',
-  'Plugins' => 'Complementos',
+  'Plugins' => 'Extensiones',
   'Pr_eferences|Preferences dialog' => 'Pr_eferencias|Diálogo de preferencias',
   'Preferences' => 'Preferencias',
   'Prefix document root' => 'Prefijo del documento raíz',
@@ -254,9 +277,12 @@ Por ejemplo un directorio "Notas" en su carpeta personal.',
   'Rename to' => 'Renombrar a',
   'Replace _all' => 'Reemplazar _todo',
   'Replace with' => 'Reemplazar con',
-  'S_ave Version...|Save Version' => '',
+  'SVN cleanup|Cleanup SVN working copy' => 'SVN cleanup|Limpiar la copia de trabajo SVN',
+  'SVN commit|Commit notebook to SVN repository' => 'SVN commit|Commit cuaderno al repositorio SVN',
+  'SVN update|Update notebook from SVN repository' => 'Actualizar SVN|Actualizar el cuaderno desde el repositorio SVN',
+  'S_ave Version...|Save Version' => 'Gu_ardar Versión...|Guardar Versión',
   'Save Copy' => 'Guardar una copia',
-  'Save version' => '',
+  'Save version' => 'Guardar versión',
   'Scanning tree ...' => 'Explorando árbol...',
   'Search' => 'Buscar',
   'Search _Backlinks...|Search Back links' => 'Buscar _Enlaces de referencia...|Buscar enlaces de referencia',
@@ -267,11 +293,11 @@ Por ejemplo un directorio "Notas" en su carpeta personal.',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Muestre el cursos incluso cuando no se puede editar la página. Esto es útil para navegación usando el teclado.',
   'Slow file system' => 'Sistema de archivos lento',
   'Source' => 'Fuente',
-  'Source Format' => '',
+  'Source Format' => 'Formato Fuente',
   'Start the side pane with the whole tree expanded.' => 'Empezar el panel lateral con todo el árbol expandido',
   'Stri_ke|Strike' => 'Tach_ar|Tachar',
   'Strike' => 'Tachar',
-  'TODO List' => 'TODO List',
+  'TODO List' => 'Lista tareas por hacer',
   'Task' => 'Tarea',
   'Tearoff menus' => 'Barra de herramientas',
   'Template' => 'Plantilla',
@@ -289,7 +315,12 @@ está perdida. No se puede editar la ecuación.',
 404',
   'This page does not have a document folder' => 'Esta página no tiene una carpeta de documentos',
   'This page does not have a source' => 'Esta página no tiene un código fuente',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'Esta página fue actualizada en el repositorio.
+Por favor actualiza tu copia de trabajo (Herramientas -> Actualizar SVN ).',
   'To_day|Today' => 'Ho_y|Hoy',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => 'Alternar Checkbox \'V\'|Alternar checkbox',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => 'Alternar Checkbox \'X\'|Alternar checkbox',
   'Underline' => 'Subrayado',
   'Updating links' => 'Actualizando vínculos',
   'Updating links in {name}' => 'Actualizar vínculos en {name}',
@@ -305,8 +336,8 @@ está perdida. No se puede editar la ecuación.',
   'User' => 'Usuario',
   'User name' => 'Nombre de usuario',
   'Verbatim' => 'Resaltar',
-  'Versions' => '',
-  'View _Annotated...' => '',
+  'Versions' => 'Versiones',
+  'View _Annotated...' => 'Ver _Anotado...',
   'View _Log' => 'Ver _registro',
   'Web browser' => 'Navegador',
   'Whole _word' => 'Toda la _palabra',
@@ -314,6 +345,9 @@ está perdida. No se puede editar la ecuación.',
   'Word Count' => 'Contar palabras',
   'Words' => 'Palabras',
   'You can add rules to your search query below' => 'Puede agregar reglas a la búsqueda debajo',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => 'Usted puede elegir entre <b>Bazaar</b> o el Sistema de Control de Versiones <b>Subversion</b>.
+Haga click en \'ayuda\' para leer los requerimientos de sistema.',
   'You have no {app_type} configured' => 'No tiene configurado {app_type}',
   'You need to restart the application
 for plugin changes to take effect.' => 'Usted necesita reiniciar la aplicación 
@@ -329,12 +363,13 @@ para que los cambios en los complementos tengan efecto.',
   '_Child|Go to child page' => '_Hija|Ir a págin hija',
   '_Close|Close window' => '_Cerrar|Cerrar ventana',
   '_Contents|Help contents' => '_Contenidos|Contenidos de ayuda',
-  '_Copy Page...|Copy page' => '',
+  '_Copy Page...|Copy page' => '_Copiar Página...|Copiar Página',
   '_Copy|Copy' => '_Copiar|Copiar',
   '_Date and Time...|Insert date' => '_Fecha y hora...|Insertar fecha',
   '_Delete Page|Delete page' => '_Borrar página|Borrar página',
   '_Delete|Delete' => '_Borrar|Borrar',
   '_Discard changes' => '_Descartar los cambios',
+  '_Edit' => '_Editar',
   '_Edit Equation' => '_Editar ecuación',
   '_Edit Link' => '_Editar vínculo',
   '_Edit Link...|Edit link' => '_Editar vínculo...|Editar vínculo',
@@ -364,12 +399,12 @@ para que los cambios en los complementos tengan efecto.',
   '_Next' => '_Siguiente',
   '_Next in index|Go to next page' => '_Siguiente en índice|Ir a la página siguiente',
   '_Normal|Normal' => '_Normal|Normal',
-  '_Notebook Changes...' => '',
+  '_Notebook Changes...' => 'Cambios al cuader_no...',
   '_Open Another Notebook...|Open notebook' => '_Abrir Otro Cuaderno de notas..|Abrir cuaderno de notas',
   '_Open link' => 'Abrir víncul_o',
   '_Overwrite' => '_Sobreescribir',
   '_Page' => '_Página',
-  '_Page Changes...' => '',
+  '_Page Changes...' => 'Cambios de la Página...',
   '_Parent|Go to parent page' => '_Padre|Ir a página padre',
   '_Paste|Paste' => '_Pegar|Pegar',
   '_Preview' => '_Vista previa',
@@ -385,7 +420,7 @@ para que los cambios en los complementos tengan efecto.',
   '_Replace' => '_Reemplazar',
   '_Replace...|Find and Replace' => '_Remplazar...|Encontrar y remplazar',
   '_Reset' => '_Restablecer',
-  '_Restore Version...' => '',
+  '_Restore Version...' => '_Restaurar Versión...',
   '_Save Copy' => '_Salvar una copia',
   '_Save a copy...' => '_Salvar una copia...',
   '_Save|Save page' => '_Guardar|Guardar página',
@@ -406,7 +441,7 @@ para que los cambios en los complementos tengan efecto.',
     'Act_ualizar {number} páginas enlazanado a ésta'
   ],
   '_Verbatim|Verbatim' => '_Resaltado|Resaltado',
-  '_Versions...|Versions' => '',
+  '_Versions...|Versions' => '_Versiones...|Versiones',
   '_View|' => '_Ver|',
   '_Word Count|Word count' => '_Contar palabras|Contar palabras',
   'other...' => 'otro/a...',
