@@ -7,18 +7,19 @@
 # TRANSLATORS:
 # Jaap Karssenberg (it)
 # Jacopo Moronato (it)
+# Matteo Ferrabone (it)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-04 12:47+0000
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-11-01 14:59+0000
 # Last-Translator: Jacopo Moronato <Unknown>
 # Language-Team: Italian <it@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2008-11-09 09:05+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -39,7 +40,10 @@ la pagina \'{name}\' ?',
   '<b>Enable Version Control</b>
 
 Version control is currently not enabled for this notebook.
-Do you want to enable it ?' => '',
+Do you want to enable it ?' => '<b>Attiva il Controllo di Versione</b>
+
+Il controllo di versione non è attualmente in uso per questo blocco note.
+Vuoi attivarlo?',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -61,7 +65,7 @@ Vuoi sovrascriverla?',
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '',
+All changes since the last saved version will be lost !' => '',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -89,7 +93,7 @@ Vuoi aggiornare questo notebook al nuovo layout?
   'Auto-increment numbered lists' => 'Auto-incrementa liste numerate',
   'Auto-link CamelCase' => 'Auto-linka Camelcase',
   'Auto-link files' => 'Auto-linka file',
-  'Auto-save version on close' => '',
+  'Auto-save version on close' => 'Salva automaticamente la versione in chiusura',
   'Auto-select words' => 'Auto-seleziona parole',
   'Automatically increment items in a numbered list' => 'Incrementa automaticamente gli oggetti in una lista numerata',
   'Automatically link file names when you type' => 'Collega automaticamente nomi dei file quando scrivi',
@@ -98,36 +102,42 @@ Vuoi aggiornare questo notebook al nuovo layout?
   'Bold' => 'Grassetto',
   'Calen_dar|Show calendar' => 'Calen_dario|Mostra il calendario',
   'Calendar' => 'Calendario',
-  'Can not save a version without comment' => '',
+  'Can not find application "bzr"' => 'Impossibile trovare l\'applicazione "bzr"',
+  'Can not find application "{name}"' => '',
+  'Can not save a version without comment' => 'Impossibile salvare una versione senza un commento',
   'Can not save to page: {name}' => 'Impossibile salvare la pagina {name}',
   'Can\'t find {url}' => 'Impossibile trovare {url}',
   'Cha_nge' => '_Modifica',
   'Chars' => 'Caratteri',
   'Check _spelling|Spell check' => 'Controllo Ortografico|Controllo ortografico',
+  'Check checkbox lists recursive' => '',
+  'Checking a checkbox list item will also check any sub-items' => '',
   'Choose {app_type}' => 'Scegli {app_type}',
   'Co_mpare Page...' => 'Co_nfronta Pagina...',
   'Command' => 'Comando',
+  'Comment' => '',
   'Compare this version with' => 'Confronta questa versione con',
   'Copy Email Address' => 'Copia indirizzo di posta elettronica',
   'Copy Location|Copy location' => 'Copia Posizione|Copia posizione della pagina',
   'Copy _Link' => 'Copia _Collegamento',
   'Could not delete page: {name}' => 'Impossibile eliminare la pagina {name}',
   'Could not get annotated source for page {page}' => '',
-  'Could not get changes for page: {page}' => '',
-  'Could not get file for page: {page}' => '',
-  'Could not get versions to compare' => '',
-  'Could not initialize version control' => '',
+  'Could not get changes for page: {page}' => 'Impossibile ottenere i cambiamenti per la pagina: {page}',
+  'Could not get changes for this notebook' => '',
+  'Could not get file for page: {page}' => 'Impossibile ottenere il file per la pagina: {page}',
+  'Could not get versions to compare' => 'Impossibile ottenere le versioni da confrontare',
+  'Could not initialize version control' => 'Impossibile inizializzare il controllo di versione',
   'Could not load page: {name}' => 'Impossibile caricare la pagina {name}',
   'Could not rename {from} to {to}' => 'Impossibile rinominare {from} con {to}',
   'Could not save page' => 'Impossibile salvare la pagina',
-  'Could not save version' => '',
+  'Could not save version' => 'Impossibile salvare versione',
   'Creating a new link directly opens the page' => 'Creando un nuovo collegamento verrà aperta direttamente la pagina',
-  'Creation Date' => '',
+  'Creation Date' => 'Data di Creazione',
   'Cu_t|Cut' => '_Taglia|Taglia',
   'Current' => 'Corrente',
   'Customise' => 'Personalizza',
   'Date' => 'Data',
-  'Default notebook' => '',
+  'Default notebook' => 'Blocco note di Default',
   'Details' => 'Dettagli',
   'Diff Editor' => '',
   'Diff editor' => '',
@@ -145,14 +155,17 @@ Vuoi aggiornare questo notebook al nuovo layout?
   'Editing' => 'Editing',
   'Email client' => 'Client mail',
   'Enabled' => 'Attivo',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => '',
   'Equation Editor' => 'Editor Equazioni',
   'Equation Editor Log' => 'Log Editor Equazioni',
   'Expand side pane' => 'Espandi pannello laterale',
   'Export page' => 'Esporta pagina',
   'Exporting page {number}' => 'Esportazione pagina {number}',
+  'Failed to cleanup SVN working copy.' => '',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'Impossibile caricare i plugin SVN,
+sono installate le utilità di subversion?',
   'Failed to load plugin: {name}' => 'Plugin {name} non caricato',
+  'Failed update working copy.' => '',
   'File browser' => 'File browser',
   'File is not a text file: {file}' => '{file} non è un file di testo',
   'Filter' => 'Filtro',
@@ -181,8 +194,9 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Home Page' => 'Home Page',
   'Icon' => 'Icona',
   'Id' => 'Id',
+  'Include all open checkboxes' => '',
   'Index page' => 'Indice',
-  'Initial version' => '',
+  'Initial version' => 'Versione iniziale',
   'Insert Date' => 'Inserisci Data',
   'Insert Image' => 'Inserisci Immagine',
   'Insert Link' => 'Inserisci Collegamento',
@@ -195,11 +209,12 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Links to' => 'Collega a',
   'Match c_ase' => 'M_aiuscole',
   'Media' => 'Media',
-  'Modification Date' => '',
+  'Modification Date' => 'Data di Modifica',
   'Name' => 'Nome',
   'New notebook' => 'Nuova repository',
   'New page' => 'Nuova pagina',
   'No such directory: {name}' => 'Nessuna directory: {name}',
+  'No such file or directory: {name}' => 'Nessun file o directory: {name}',
   'No such file: {file}' => '{file} non esiste',
   'No such notebook: {name}' => 'Nessun contenitore: {name}',
   'No such page: {page}' => 'Nessuna pagina:{page}',
@@ -225,8 +240,9 @@ automaticamente causa la creazione di una nuova pagina.',
   'Page Editable|Page editable' => 'Pagina Modificabile|Pagina modificabile',
   'Page name' => 'Nome pagina',
   'Pages' => 'Pagine',
-  'Please enter a comment for this version' => '',
-  'Please enter a name to save a copy of page: {page}' => '',
+  'Password' => '',
+  'Please enter a comment for this version' => 'Per favore inserire un commento per questa versione',
+  'Please enter a name to save a copy of page: {page}' => 'Inserire un nome per salvare una copia della pagina: {page}',
   'Please enter a {app_type}' => 'Inserisci un {app_type}',
   'Please give a page first' => 'Specificare la pagina',
   'Please give at least a directory to store your pages.
@@ -234,7 +250,9 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Per favore specifica almeno una directory in cui salvare le tue pagine.
 Se si tratta di un nuovo notebook, dovresti specificare una directory vuota. 
 Per esempio una directory "Note" nell tua home directory.',
-  'Please select a notebook first' => '',
+  'Please provide the password for
+{path}' => '',
+  'Please select a notebook first' => 'Prima scegliere un blocco note',
   'Please select a version first' => 'Selezionare una versione',
   'Plugin already loaded: {name}' => 'Plugin {name} già attivo',
   'Plugins' => 'Moduli',
@@ -252,9 +270,12 @@ Per esempio una directory "Note" nell tua home directory.',
   'Rename to' => 'Rinomina come',
   'Replace _all' => 'Sostituisci _tutto',
   'Replace with' => 'Sostituisci con',
-  'S_ave Version...|Save Version' => '',
+  'SVN cleanup|Cleanup SVN working copy' => '',
+  'SVN commit|Commit notebook to SVN repository' => '',
+  'SVN update|Update notebook from SVN repository' => '',
+  'S_ave Version...|Save Version' => 'A_alva Versione...|Salva Versione',
   'Save Copy' => 'Salva Copia',
-  'Save version' => '',
+  'Save version' => 'Salva versione',
   'Scanning tree ...' => 'Scansione albero...',
   'Search' => 'Cerca',
   'Search _Backlinks...|Search Back links' => 'Cerca _Backlinks...|Cerca Backlinks',
@@ -265,7 +286,7 @@ Per esempio una directory "Note" nell tua home directory.',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Mostra il cursore anche se non puoi modificare la pagina. Questo è utile per il browsing basato sulla tastiera.',
   'Slow file system' => 'File System remoto',
   'Source' => 'Fonte',
-  'Source Format' => '',
+  'Source Format' => 'Formato Sorgente',
   'Start the side pane with the whole tree expanded.' => 'Avvia il pannello laterale con l\'intero albero espanso',
   'Stri_ke|Strike' => '_Barrato|Barrato',
   'Strike' => 'Barrato',
@@ -287,7 +308,11 @@ non è stata trovata. Impossibile modificare l\'equazione.',
 404',
   'This page does not have a document folder' => 'Questa pagina non ha una cartella che la contiene',
   'This page does not have a source' => 'Questa pagina non ha una sorgente',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => '',
   'To_day|Today' => '_Oggi|Crea una pagina con la data odierna',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Sottolineato',
   'Updating links' => 'Aggiornamento link',
   'Updating links in {name}' => 'Aggiornamento link in {name}',
@@ -312,6 +337,8 @@ non è stata trovata. Impossibile modificare l\'equazione.',
   'Word Count' => 'Conta Parole',
   'Words' => 'Parole',
   'You can add rules to your search query below' => 'Puoi aggiungere regole alla tua ricerca qui sotto',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '',
   'You have no {app_type} configured' => 'Non hai {app_type} configurati',
   'You need to restart the application
 for plugin changes to take effect.' => 'Riavvia l\'applicazione
@@ -327,12 +354,13 @@ affinchè i cambiamenti abbiano effetto.',
   '_Child|Go to child page' => '_Giù|Vai alla pagina figlia',
   '_Close|Close window' => '_Chiudi|Chiudi la finestra',
   '_Contents|Help contents' => '_Sommario|Guida di Zim Desktop Wiki',
-  '_Copy Page...|Copy page' => '',
+  '_Copy Page...|Copy page' => '_Copia Pagina...|Copia Pagina',
   '_Copy|Copy' => '_Copia|Copia',
   '_Date and Time...|Insert date' => '_Data e Ora...|Inserisci la data e l\'ora',
   '_Delete Page|Delete page' => '_Elimina Pagina|Elimina la pagina',
   '_Delete|Delete' => '_Elimina|Elimina',
   '_Discard changes' => '_Scarta modifiche',
+  '_Edit' => '',
   '_Edit Equation' => '_Modifica Equazione',
   '_Edit Link' => '_Modifica Link',
   '_Edit Link...|Edit link' => '_Modifica Collegamento...|Modifica il collegamento',
