@@ -9,15 +9,15 @@
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-08 09:53+0000
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-11-05 21:59+0000
 # Last-Translator: João Santos <twocool.pt@gmail.com>
 # Language-Team: Portuguese <pt@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -38,7 +38,10 @@ a página \'{name}\' ?',
   '<b>Enable Version Control</b>
 
 Version control is currently not enabled for this notebook.
-Do you want to enable it ?' => '',
+Do you want to enable it ?' => '<b>Activar Controle de Versão</b>
+
+O controle de versão não está activo neste bloco de notas.
+Deseja activa-lo?',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -60,7 +63,7 @@ Deseja substitui-la?',
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '',
+All changes since the last saved version will be lost !' => '',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -97,25 +100,31 @@ Deseja actualizar o seu bloco de notas para usar o novo formato?
   'Bold' => 'Negrito',
   'Calen_dar|Show calendar' => 'Calen_dário|Mostrar Calendário',
   'Calendar' => 'Calendário',
+  'Can not find application "bzr"' => 'Não foi possível encontrar a aplicação "bzr"',
+  'Can not find application "{name}"' => 'Não foi possível encontrar a aplicação "{name}"',
   'Can not save a version without comment' => 'Não é possível guardar uma versão sem um comentário',
   'Can not save to page: {name}' => 'Não foi possível gravar para a página: {name}',
   'Can\'t find {url}' => 'Não foi possível encontrar {url}',
   'Cha_nge' => '_Mudar',
   'Chars' => 'Caracteres',
   'Check _spelling|Spell check' => 'Verificar _ortografica|Verificar Ortografica',
+  'Check checkbox lists recursive' => '',
+  'Checking a checkbox list item will also check any sub-items' => '',
   'Choose {app_type}' => 'Escolha {app_type}',
   'Co_mpare Page...' => 'Co_mparar Página...',
   'Command' => 'Comando',
+  'Comment' => 'Comentário',
   'Compare this version with' => 'Comparar esta versão com',
   'Copy Email Address' => 'Copy endereço de Email',
   'Copy Location|Copy location' => 'Copiar Localização|Copiar Localização',
   'Copy _Link' => 'Copiar _Ligação',
   'Could not delete page: {name}' => 'Não foi possível apagar página: {name}',
-  'Could not get annotated source for page {page}' => '',
-  'Could not get changes for page: {page}' => '',
-  'Could not get file for page: {page}' => '',
-  'Could not get versions to compare' => '',
-  'Could not initialize version control' => '',
+  'Could not get annotated source for page {page}' => 'Não foi possível encontrar a fonte anotada para a página {page}',
+  'Could not get changes for page: {page}' => 'Não foi possível encontrar as alterações para esta página: {page}',
+  'Could not get changes for this notebook' => 'Não foi possível encontrar as alterações para este bloco de notas',
+  'Could not get file for page: {page}' => 'Não foi possível encontrar o ficheiro desta página: {page}',
+  'Could not get versions to compare' => 'Não foi possível encontrar as versões para comparar',
+  'Could not initialize version control' => 'Não foi possível iniciar o controle de versão',
   'Could not load page: {name}' => 'Não foi possível carregar a página: {name}',
   'Could not rename {from} to {to}' => 'Não foi possível renomear {from} para {to}',
   'Could not save page' => 'Não foi possível gravar página',
@@ -126,7 +135,7 @@ Deseja actualizar o seu bloco de notas para usar o novo formato?
   'Current' => 'Actual',
   'Customise' => 'Personalizar',
   'Date' => 'Data',
-  'Default notebook' => '',
+  'Default notebook' => 'Bloco de notas padrão',
   'Details' => 'Detalhes',
   'Diff Editor' => '',
   'Diff editor' => '',
@@ -144,14 +153,17 @@ Deseja actualizar o seu bloco de notas para usar o novo formato?
   'Editing' => 'Edição',
   'Email client' => 'Cliente de e-mail',
   'Enabled' => 'Activo',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => '',
   'Equation Editor' => 'Editor de Equações',
   'Equation Editor Log' => 'Registo do Editor de Equações',
   'Expand side pane' => 'Expandir painel lateral',
   'Export page' => 'Exportar página',
   'Exporting page {number}' => 'Exportando página {number}',
+  'Failed to cleanup SVN working copy.' => '',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'Falha ao carregar o plugin SVN,
+tem as ferramentas subversion instaladas?',
   'Failed to load plugin: {name}' => 'Não foi possivel carregar plugin: {name}',
+  'Failed update working copy.' => 'Falha ao actualizar cópia de trabalho',
   'File browser' => 'Navegador de ficheiros',
   'File is not a text file: {file}' => 'Não é um ficheiro de texto: {file}',
   'Filter' => 'Filtro',
@@ -180,6 +192,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Home Page' => 'Página Inicial',
   'Icon' => 'Ícone',
   'Id' => 'Id',
+  'Include all open checkboxes' => '',
   'Index page' => 'Página de Índice',
   'Initial version' => 'Versão Inicial',
   'Insert Date' => 'Inserir data',
@@ -199,6 +212,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'New notebook' => 'Novo bloco de notas',
   'New page' => 'Nova Página',
   'No such directory: {name}' => 'Directório inexistente: {name}',
+  'No such file or directory: {name}' => 'Ficheiro ou directório inexistente: {name}',
   'No such file: {file}' => 'Ficheiro inexistente: {file}',
   'No such notebook: {name}' => 'Bloco de notas inexistente: {name}',
   'No such page: {page}' => 'Página inexistente: {page}',
@@ -224,6 +238,7 @@ irá automaticamente criar uma nova página.',
   'Page Editable|Page editable' => 'Página Editável|Página Editável',
   'Page name' => 'Nome da Página',
   'Pages' => 'Páginas',
+  'Password' => 'Palavra-passe',
   'Please enter a comment for this version' => 'Insira um comentário para esta versão',
   'Please enter a name to save a copy of page: {page}' => 'Insira um nome para guardar uma cópia da página: {page}',
   'Please enter a {app_type}' => 'Por favor insira um {app_type}',
@@ -233,7 +248,10 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Por favor indique pelo menos um directório para guardar as suas páginas.
 Para um novo bloco de notas este deve ser um directório vazio.
 Por exemplo um directório "Notas" na sua pasta pessoal.',
-  'Please select a notebook first' => '',
+  'Please provide the password for
+{path}' => 'Por favor insira a palavra-chave para
+{path}',
+  'Please select a notebook first' => 'Por favor seleccione um bloco de notas primeiro',
   'Please select a version first' => 'Por favor seleccione um versão',
   'Plugin already loaded: {name}' => 'Plugin já carregado: {name}',
   'Plugins' => '\'Plugins\'',
@@ -251,6 +269,9 @@ Por exemplo um directório "Notas" na sua pasta pessoal.',
   'Rename to' => 'Renomear Página',
   'Replace _all' => 'Substituir _tudo',
   'Replace with' => 'Substituir por',
+  'SVN cleanup|Cleanup SVN working copy' => '',
+  'SVN commit|Commit notebook to SVN repository' => 'Submeter SVN|Submeter bloco de notas para um repositório SVN',
+  'SVN update|Update notebook from SVN repository' => 'Actualização SVN|Actualiza o bloco de notas a partir de um repositório SVN',
   'S_ave Version...|Save Version' => 'Guardar Ver_são...|Guardar Versão',
   'Save Copy' => 'Gravar cópia',
   'Save version' => 'Guardar versão',
@@ -264,7 +285,7 @@ Por exemplo um directório "Notas" na sua pasta pessoal.',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Mostrar o cursor mesmo quando não pode editar a página. Isto é útil para navegar com o teclado.',
   'Slow file system' => 'Sistema de Ficheiros lento',
   'Source' => 'Fonte',
-  'Source Format' => '',
+  'Source Format' => 'Formato da origem',
   'Start the side pane with the whole tree expanded.' => 'Iniciar o painel lateral com a árvore expandida',
   'Stri_ke|Strike' => 'R_iscado|Riscado',
   'Strike' => 'Riscar',
@@ -286,7 +307,12 @@ não existe. Não é possível editar a equação.',
 404',
   'This page does not have a document folder' => 'Esta página não tem uma pasta de documento',
   'This page does not have a source' => 'Esta página não tem uma fonte',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'Esta página foi actualizada no repositório,
+Por favor actualize a sua cópia de trabalho (Ferramentas -> Actualização SVN).',
   'To_day|Today' => 'Ho_je|Hoje',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Sublinhar',
   'Updating links' => 'Actualizando ligações',
   'Updating links in {name}' => 'Actualizando ligações em {name}',
@@ -311,6 +337,9 @@ não existe. Não é possível editar a equação.',
   'Word Count' => 'Contar Palavras',
   'Words' => 'Palavras',
   'You can add rules to your search query below' => 'Pode adicionar regras à sua consulta em baixo',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => 'Pode usar o sistema de controlo de versão <b>Bazaar</b> ou <b>Subversion</b>.
+Por favor clique \'ajuda\' para se informar sobre os requisitos do sistema.',
   'You have no {app_type} configured' => 'Não tem nenhum {app_type} configurado',
   'You need to restart the application
 for plugin changes to take effect.' => 'É necessário reiniciar a aplicação para as
@@ -332,6 +361,7 @@ for plugin changes to take effect.' => 'É necessário reiniciar a aplicação p
   '_Delete Page|Delete page' => 'Apa_gar Página|Apagar Página',
   '_Delete|Delete' => '_Apagar|Apagar',
   '_Discard changes' => '_Descartar as alterações',
+  '_Edit' => '_Editar',
   '_Edit Equation' => '_Editar Equação',
   '_Edit Link' => '_Editar Ligação',
   '_Edit Link...|Edit link' => '_Editar Ligação...|Editar ligação',
